==> crm-interface-2.8.0.RELEASE-sources.jar: cn/kinyun/crm/common/service/CrmLeadsService.java <==
/*
 * kinyun.cn Inc.
 * Copyright (c) 2021. All Rights Reserved.
 */
package cn.kinyun.crm.common.service;

import cn.kinyun.crm.common.service.dto.req.CrmLeadsInfoReq;
import cn.kinyun.crm.common.service.dto.req.CrmLeadsReq;
import cn.kinyun.crm.common.service.dto.req.CrmModMobileReq;
import cn.kinyun.crm.common.service.dto.req.LeadsStatisticsReq;
import cn.kinyun.crm.common.service.dto.resp.CrmLeadsInfoResp;

import java.util.List;
import java.util.Map;

/**
 * desc:
 *
 * @author yanmaoyuan
 * @date 2021/10/17
 */
public interface CrmLeadsService {

    /**
     * 查询线索
     *
     * @param params 线索信息
     * @return 线索ID
     */
    CrmLeadsInfoResp getLeads(CrmLeadsInfoReq params);

    /**
     * 查询线索
     *
     * @param params 线索信息
     * @return 线索ID
     */
    List<CrmLeadsInfoResp> getLeadsList(CrmLeadsInfoReq params);

    /**
     * 添加线索
     *
     * @param params 线索信息
     * @return 线索ID
     */
    CrmLeadsInfoResp addLeads(CrmLeadsReq params);

    /**
     * 修改线索手机号
     *
     * @param params 线索信息
     * @return 线索ID
     */
    void modAdLeads(CrmLeadsReq params);

    /**
     * 修改线索手机号
     *
     * @param params 线索信息
     * @return 线索ID
     */
    void modScrmLeads(CrmLeadsReq params);


    /**
     * 修改线索手机号
     *
     * @param params 线索信息
     * @return 线索ID
     */
    void modMobiles(CrmModMobileReq params);

    boolean exists(CrmLeadsInfoReq params);

    /**
     * 根据线索num查询分配情况
     *
     * @param bizId
     * @param leadsLibNums
     * @param productLineNum
     * @return
     */
    Map<String, String> getAllocTarget(Long bizId, String productLineNum, List<String> leadsLibNums);

    boolean existMobileOrNameByLeadsNum(CrmLeadsInfoReq params);

    List<CrmLeadsInfoResp> countLeadsByBindUserId(LeadsStatisticsReq param);

    List<CrmLeadsInfoResp> queryBindInfoByMobile(CrmLeadsInfoReq param);

}

==> crm-interface-2.41.3.RELEASE-sources.jar: cn/kinyun/crm/common/service/CrmLeadsService.java <==
/*
 * kinyun.cn Inc.
 * Copyright (c) 2021. All Rights Reserved.
 */
package cn.kinyun.crm.common.service;

import cn.kinyun.crm.common.enums.LeadsViewStatus;
import cn.kinyun.crm.common.service.dto.req.*;
import cn.kinyun.crm.common.service.dto.resp.CrmLeadsInfoResp;
import cn.kinyun.crm.common.service.dto.resp.LeadsChannelDataResp;
import cn.kinyun.crm.common.service.dto.resp.MobileCustomerDataResp;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * desc:
 *
 * @author yanmaoyuan
 * @date 2021/10/17
 */
public interface CrmLeadsService {

    /**
     * 查询线索
     *
     * @param params 线索信息
     * @return 线索ID
     */
    CrmLeadsInfoResp getLeads(CrmLeadsInfoReq params);

    /**
     * 查询线索
     *
     * @param params 线索信息
     * @return 线索ID
     */
    List<CrmLeadsInfoResp> getLeadsList(CrmLeadsInfoReq params);

    /**
     * 添加线索
     *
     * @param params 线索信息
     * @return 线索ID
     */
    CrmLeadsInfoResp addLeads(CrmLeadsReq params);

    /**
     * 使用参数中不为空的字段修改线索中为空的字段
     * @param params
     */
    void modLeadsByNotEmptyField(CrmLeadsReq params);

    /**
     * 修改线索手机号
     *
     * @param params 线索信息
     * @return 线索ID
     */
    void modAdLeads(CrmLeadsReq params);

    /**
     * 修改线索手机号
     *
     * @param params 线索信息
     * @return 线索ID
     */
    void modScrmLeads(CrmLeadsReq params);


    /**
     * 修改线索手机号
     *
     * @param params 线索信息
     * @return 线索ID
     */
    void modMobiles(CrmModMobileReq params);

    boolean exists(CrmLeadsInfoReq params);

    /**
     * 根据线索num查询分配情况
     *
     * @param bizId
     * @param leadsLibNums
     * @param productLineNum
     * @return
     */
    Map<String, String> getAllocTarget(Long bizId, String productLineNum, List<String> leadsLibNums);

    boolean existMobileOrNameByLeadsNum(CrmLeadsInfoReq params);

    List<CrmLeadsInfoResp> countLeadsByBindUserId(LeadsStatisticsReq param);

    List<CrmLeadsInfoResp> queryBindInfoByMobile(CrmLeadsInfoReq param);

    MobileCustomerDataResp getMobileCustomerDataByTime(MobileCustomerDataReq req);

    List<LeadsChannelDataResp> getChannelData(ChannelDataReq req);
    void modLeadsAndAllocateAllInfo(CrmLeadsReq leadsReq);

    void updateLeadsToFollowed(Long bizId, String contactId);

    /**
     * 更新线索的"最近刷新时间"
     * LeadsViewStatus 为空则不更新LeadsViewInfo
     */
    void updateLeadsLatestRefreshTime(Long bizId, String mobile, Date refreshTime, LeadsViewStatus leadsViewStatus);

    /**
     * 获取手机号对应的线索的最早的绑定人
     */
    Long getLeadsBindingUserId(Long bizId, String mobile);
}
